@@ -11,11 +11,11 @@ import argparse
 import logging
 from subprocess import Popen, PIPE, STDOUT
 
-file_handler = logging.FileHandler(filename='nustar_utils_%s.log' % (strftime("%Y-%m-%dT%H:%M:%S", gmtime())))
-stdout_handler = logging.StreamHandler(sys.stdout)
-handlers = [stdout_handler, file_handler]
-
-logging.basicConfig(level=logging.INFO, format=' %(levelname)s - %(message)s', handlers=handlers)
+# file_handler = logging.FileHandler(filename='nustar_process_%s.log' % (strftime("%Y-%m-%dT%H:%M:%S", gmtime())))
+# stdout_handler = logging.StreamHandler(sys.stdout)
+# handlers = [stdout_handler, file_handler]
+#
+# logging.basicConfig(level=logging.INFO, format=' %(levelname)s - %(message)s', handlers=handlers)
 #[%(asctime)s] {%(filename)s:%(lineno)d}
 logger = logging.getLogger()
 
