@@ -940,7 +940,7 @@ def get_fourier_coeff(pulse):
 
     return phi0, phi0_2, a, a2
 
-def get_fourier_coeff_error( counts, counts_err, n_simul=100):
+def get_fourier_coeff_error( counts, counts_err, n_simul=100, use_poisson=False):
 
     sim_phi0 = []
     sim_phi0_2 = []
@@ -948,7 +948,10 @@ def get_fourier_coeff_error( counts, counts_err, n_simul=100):
     sim_A2 = []
 
     for i in range(n_simul):
-        fp = random.gauss(counts, counts_err)
+        if use_poisson:
+            fp = random.poisson(counts)
+        else:
+            fp = random.normal(counts, counts_err)
         phi0, phi0_2, A, A2 = get_fourier_coeff(fp)
         sim_phi0.append(phi0)
         sim_phi0_2.append(phi0_2)
@@ -1005,7 +1008,14 @@ def write_orbit_file_from_gbm_page(url, file_name='orbit.dat',
         for kk in orbital_parameters:
             if 'T' in kk:
                 t_90 = Time(orbit[kk], format='jd')
-                ff.write('%f\n' % (t_90.mjd - 0.25 * float(orbit['Orbital Period'])))
+                # The orbit file contains the longitude of periastron or the lower conjunction
+                if float(orbit['Eccentricity']) >= 0.:
+                    logger.debug('Special eccentricity')
+                    ff.write('%f\n' % (t_90.mjd + (float(orbit['periastron']) - 90.)/360. *\
+                                       float(orbit['Orbital Period'])))
+                else:
+                    logger.debug('Non Special eccentricity')
+                    ff.write('%f\n' % (t_90.mjd - 0.25 * float(orbit['Orbital Period'])))
             else:
                 ff.write(orbit[kk] + '\n')
 
@@ -1035,13 +1045,17 @@ def get_cross_correlation(pp, plot=False):
     lag[lag > (pp.shape[1]/2)] -= pp.shape[1]
     return lag, np.array(correlation)
 
-def get_cross_correlation_error(pp, dpp, n_simul=100):
+def get_cross_correlation_error(pp, dpp, n_simul=100, use_poisson=False):
 
     fake_lags = np.empty([n_simul, pp.shape[0]], dtype=float)
     fake_corrs = np.empty([n_simul, pp.shape[0]], dtype=float)
 
     for i in range(n_simul):
-        fake_pp = random.gauss(pp, dpp)
+        if use_poisson:
+            fake_pp = random.poisson(pp)
+        else:
+            fake_pp = random.normal(pp, dpp)
+
         fake_lags[i, :], fake_corrs[i, :] = get_cross_correlation(fake_pp)
 
     return np.std(fake_lags, 0), np.std(fake_corrs, 0)
